# ChessTab - About

ChessTab lists the games on a database and displays the scores of selected games.

This is ChessTab-0.41.5

python setup.py install will have installed these packages:

- chesstab-0.41.5
- basesup-0.21.5
- gridsup-0.19.9
- pgn-0.10.3
- rmappsup-0.38.10
- uci-0.1.1

ChessTab is built on Python3.3 and uses features introduced at Python3.2.

Dependencies:

> Python3.3, or later versions when available, must be installed to run ChessTab.

> tkinter, part of Python, must be installed to run ChessTab. Sometimes this is installed separately.

> tkinter must be using tk8.6.

Licence:

> a copy of the ChessTab licence is at <package folder>/chesstab/about/LICENCE

Contact:

> see <package folder>/chesstab/about/CONTACT

<package folder> is where chesstab is installed, usually site-packages in the Python installation.